@@ -181,7 +181,7 @@ class SSHClient(object):
                     raise RuntimeError("ssh transport is not active and failed to reconnect.")
             return self._exec(cmd,promt_response,timeout)
         except Exception as e:
-            log.warning(f"when run cmd: {cmd}, meets exception.", exc_info=True)
+            log.warning(f"when run cmd: {cmd}, meets exception, err msg is {str(e)}")
             return ExecResult(1, "", str(e))
 
     def _scp_to_remote(self, local_path, remote_path):
